@@ -15,20 +15,20 @@ Usage::
 from datetime import datetime
 from typing import Any, Dict, List, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
     ApplicationUpdateTypeDef,
     CloudWatchLoggingOptionTypeDef,
-    CreateApplicationResponseResponseTypeDef,
-    DescribeApplicationResponseResponseTypeDef,
-    DiscoverInputSchemaResponseResponseTypeDef,
+    CreateApplicationResponseTypeDef,
+    DescribeApplicationResponseTypeDef,
+    DiscoverInputSchemaResponseTypeDef,
     InputConfigurationTypeDef,
     InputProcessingConfigurationTypeDef,
     InputStartingPositionConfigurationTypeDef,
     InputTypeDef,
-    ListApplicationsResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
+    ListApplicationsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     OutputTypeDef,
     ReferenceDataSourceTypeDef,
     S3ConfigurationTypeDef,
@@ -62,14 +62,19 @@ class Exceptions:
     UnsupportedOperationException: Type[BotocoreClientError]
 
 
-class KinesisAnalyticsClient:
+class KinesisAnalyticsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        KinesisAnalyticsClient exceptions.
+        """
 
     def add_application_cloud_watch_logging_option(
         self,
@@ -81,7 +86,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_cloud_watch_logging_option)
         """
 
@@ -91,7 +96,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_input)
         """
 
@@ -106,7 +111,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_input_processing_configuration)
         """
 
@@ -116,7 +121,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_output)
         """
 
@@ -130,7 +135,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_reference_data_source)
         """
 
@@ -138,7 +143,7 @@ class KinesisAnalyticsClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#can_paginate)
         """
 
@@ -152,11 +157,11 @@ class KinesisAnalyticsClient:
         CloudWatchLoggingOptions: List["CloudWatchLoggingOptionTypeDef"] = None,
         ApplicationCode: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateApplicationResponseResponseTypeDef:
+    ) -> CreateApplicationResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#create_application)
         """
 
@@ -166,7 +171,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application)
         """
 
@@ -180,7 +185,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_cloud_watch_logging_option)
         """
 
@@ -190,7 +195,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_input_processing_configuration)
         """
 
@@ -200,7 +205,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_output)
         """
 
@@ -210,17 +215,15 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_reference_data_source)
         """
 
-    def describe_application(
-        self, *, ApplicationName: str
-    ) -> DescribeApplicationResponseResponseTypeDef:
+    def describe_application(self, *, ApplicationName: str) -> DescribeApplicationResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#describe_application)
         """
 
@@ -232,11 +235,11 @@ class KinesisAnalyticsClient:
         InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = None,
         S3Configuration: "S3ConfigurationTypeDef" = None,
         InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = None
-    ) -> DiscoverInputSchemaResponseResponseTypeDef:
+    ) -> DiscoverInputSchemaResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#discover_input_schema)
         """
 
@@ -250,27 +253,25 @@ class KinesisAnalyticsClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#generate_presigned_url)
         """
 
     def list_applications(
         self, *, Limit: int = None, ExclusiveStartApplicationName: str = None
-    ) -> ListApplicationsResponseResponseTypeDef:
+    ) -> ListApplicationsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#list_applications)
         """
 
-    def list_tags_for_resource(
-        self, *, ResourceARN: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
         """
         Retrieves the list of key-value tags assigned to the application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#list_tags_for_resource)
         """
 
@@ -280,7 +281,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#start_application)
         """
 
@@ -288,7 +289,7 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#stop_application)
         """
 
@@ -296,7 +297,7 @@ class KinesisAnalyticsClient:
         """
         Adds one or more key-value tags to a Kinesis Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#tag_resource)
         """
 
@@ -304,7 +305,7 @@ class KinesisAnalyticsClient:
         """
         Removes one or more tags from a Kinesis Analytics application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#untag_resource)
         """
 
@@ -318,6 +319,6 @@ class KinesisAnalyticsClient:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#update_application)
         """
